Documentation
¶
Overview ¶
Package env detects what sort of environment Camlistore is running in.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DebugUploads ¶
func DebugUploads() bool
DebugUploads reports whether this is a debug environment for uploads.
Types ¶
This section is empty.
Source Files
¶
- env.go
- env_nojs.go
Click to show internal directories.
Click to hide internal directories.